
{% comment %}
Create a target element
load the compiled bundle
instantiate the bundle with the json context
{% endcomment %}
{% load static %}
{% block svelte_styles %}
    {# {{ block.super }} #}
    <link href="{{ css_bundle_url }}" rel="stylesheet">
{% endblock %}

<div id="{{ element_id }}"></div>

{{ props|json_script:props_name }}
<script type="text/javascript" src="{{ bundle_url }}"></script>
